Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(226)

Unified Diff: services/ui/ws/drag_controller_unittest.cc

Issue 2849083002: Add pointer id to the WebMouseEvent's constructors (Closed)
Patch Set: webmouseid Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/ui/ws/drag_controller_unittest.cc
diff --git a/services/ui/ws/drag_controller_unittest.cc b/services/ui/ws/drag_controller_unittest.cc
index 6e10d0fa1fdad18c976089fa1bcf4eb6561cc8a9..ecae467ba363266483effdb1993fdc6d2f020a00 100644
--- a/services/ui/ws/drag_controller_unittest.cc
+++ b/services/ui/ws/drag_controller_unittest.cc
@@ -156,7 +156,8 @@ class DragControllerTest : public testing::Test,
window->PerformOnDragDropStart(
std::unordered_map<std::string, std::vector<uint8_t>>());
drag_operation_ = base::MakeUnique<DragController>(
- this, this, window->window(), window, MouseEvent::kMousePointerId,
+ this, this, window->window(), window,
+ MouseEvent::kDefaultMousePointerId,
std::unordered_map<std::string, std::vector<uint8_t>>(),
drag_operations);
@@ -628,7 +629,7 @@ TEST_F(DragControllerTest, CancelDrag) {
TEST_F(DragControllerTest, IgnoreEventsFromOtherPointers) {
std::unique_ptr<DragTestWindow> window = BuildWindow();
// This starts the operation with MouseEvent::kMousePointerId.
StartDragOperation(window.get(), ui::mojom::kDropEffectMove);
// Ignore events from pointer 5.
@@ -628,7 +629,7 @@ TEST_F(DragControllerTest, CancelDrag) {
TEST_F(DragControllerTest, IgnoreEventsFromOtherPointers) {
std::unique_ptr<DragTestWindow> window = BuildWindow();
- // This starts the operation with MouseEvent::kMousePointerId.
+ // This starts the operation with MouseEvent::kDefaultMousePointerId.
StartDragOperation(window.get(), ui::mojom::kDropEffectMove);
// Ignore events from pointer 5.

Powered by Google App Engine
This is Rietveld 408576698